searchData={"content_type":"text/markdown","items":[{"doc":"A way to look for specific sec filing fields in 10-k, 10-q, and 8-k filings.","ref":"ExtractorApi.html","title":"ExtractorApi","type":"module"},{"doc":"Determines the filing type (10-K, 10-Q, or 8-K) from the URL.","ref":"ExtractorApi.html#determine_filing_type/1","title":"ExtractorApi.determine_filing_type/1","type":"function"},{"doc":"Extracts a section from an SEC filing.","ref":"ExtractorApi.html#extract/3","title":"ExtractorApi.extract/3","type":"function"},{"doc":"- url: URL of the SEC filing\n  - item: Section item to extract\n  - opts: Additional options including :api_key and :type","ref":"ExtractorApi.html#extract/3-parameters","title":"Parameters - ExtractorApi.extract/3","type":"function"},{"doc":"# Extract Risk Factors (Item 1A) from a 10-K filing\n    iex> SecioEx.ExtractorApi.extract(\n      \"https://www.sec.gov/.../tsla-10k_20201231.htm\",\n      \"1A\",\n      api_key: \"your_api_key\"\n    )\n    {:ok, \"Risk Factors content...\"}\n\n    # Extract with HTML formatting\n    iex> SecioEx.ExtractorApi.extract(\n      \"https://www.sec.gov/.../aapl-20210327.htm\",\n      \"8\",\n      api_key: \"your_api_key\",\n      type: \"html\"\n    )\n    {:ok, \" Financial Statements content... \"}","ref":"ExtractorApi.html#extract/3-examples","title":"Examples - ExtractorApi.extract/3","type":"function"},{"doc":"Validates that the requested item is valid for the filing type.","ref":"ExtractorApi.html#validate_item/2","title":"ExtractorApi.validate_item/2","type":"function"},{"doc":"Validates the return type (text or html).","ref":"ExtractorApi.html#validate_return_type/1","title":"ExtractorApi.validate_return_type/1","type":"function"},{"doc":"A module that connects to and utilizes the sec-api.io API.\nProvides access to Query API, Stream API, and Full-Text Search functionality.","ref":"SecioEx.html","title":"SecioEx","type":"module"},{"doc":"# Query API\n    {:ok, results} = SecioEx.QueryApi.search(\"formType:\"10-K\"\", api_key: \"your_api_key\")\n\n    # Full-Text Search\n    {:ok, results} = SecioEx.FullTextSearch.search(\"SpaceX\", \n      form_types: [\"8-K\", \"10-Q\"],\n      api_key: \"your_api_key\"\n    )\n\n    # Stream API\n    {:ok, results} = SecioEx.StreamApi.stream(api_key: \"your_api_key\")","ref":"SecioEx.html#module-examples","title":"Examples - SecioEx","type":"module"},{"doc":"Generate Pdf's and download filings and files from the SEC database.","ref":"SecioEx.DownloadApi.html","title":"SecioEx.DownloadApi","type":"module"},{"doc":"Downloads a filing or exhibit from SEC EDGAR.","ref":"SecioEx.DownloadApi.html#download/2","title":"SecioEx.DownloadApi.download/2","type":"function"},{"doc":"- path: The path to the file on SEC EDGAR (after /data/)\n  - opts: Keyword list of options including :api_key","ref":"SecioEx.DownloadApi.html#download/2-parameters","title":"Parameters - SecioEx.DownloadApi.download/2","type":"function"},{"doc":"iex> SecioEx.DownloadApi.download(\n      \"815094/000156459021006205/abmd-8k_20210211.htm\",\n      api_key: \"your_api_key\"\n    )\n    {:ok, \"filing content...\"}","ref":"SecioEx.DownloadApi.html#download/2-examples","title":"Examples - SecioEx.DownloadApi.download/2","type":"function"},{"doc":"Downloads a filing by CIK and accession number.","ref":"SecioEx.DownloadApi.html#download_by_identifiers/4","title":"SecioEx.DownloadApi.download_by_identifiers/4","type":"function"},{"doc":"- cik: The CIK number (without leading zeros)\n  - accession_no: The accession number (with hyphens removed)\n  - filename: The filename of the document\n  - opts: Keyword list of options including :api_key","ref":"SecioEx.DownloadApi.html#download_by_identifiers/4-parameters","title":"Parameters - SecioEx.DownloadApi.download_by_identifiers/4","type":"function"},{"doc":"iex> SecioEx.DownloadApi.download_by_identifiers(\n      \"815094\",\n      \"000156459021006205\",\n      \"abmd-8k_20210211.htm\",\n      api_key: \"your_api_key\"\n    )\n    {:ok, \"filing content...\"}","ref":"SecioEx.DownloadApi.html#download_by_identifiers/4-examples","title":"Examples - SecioEx.DownloadApi.download_by_identifiers/4","type":"function"},{"doc":"Generates a PDF from a filing or exhibit.","ref":"SecioEx.DownloadApi.html#generate_pdf/2","title":"SecioEx.DownloadApi.generate_pdf/2","type":"function"},{"doc":"- url: The full SEC.gov URL of the filing or exhibit\n  - opts: Keyword list of options including :api_key","ref":"SecioEx.DownloadApi.html#generate_pdf/2-parameters","title":"Parameters - SecioEx.DownloadApi.generate_pdf/2","type":"function"},{"doc":"iex> SecioEx.DownloadApi.generate_pdf(\n      \"https://www.sec.gov/Archives/edgar/data/320193/000032019323000106/aapl-20230930.htm\",\n      api_key: \"your_api_key\"\n    )\n    {:ok, < >}","ref":"SecioEx.DownloadApi.html#generate_pdf/2-examples","title":"Examples - SecioEx.DownloadApi.generate_pdf/2","type":"function"},{"doc":"A way to do a Full text search of SEC filings and get back a list of them.","ref":"SecioEx.FullTextSearch.html","title":"SecioEx.FullTextSearch","type":"module"},{"doc":"Performs a full-text search across SEC EDGAR filings.","ref":"SecioEx.FullTextSearch.html#search/2","title":"SecioEx.FullTextSearch.search/2","type":"function"},{"doc":"- query: String containing the search term or phrase\n  - opts: Keyword list of options\n    - form_types: List of form types to search (e.g., [\"8-K\", \"10-K\"])\n    - start_date: Start date in \"YYYY-MM-DD\" format\n    - end_date: End date in \"YYYY-MM-DD\" format\n    - ciks: List of CIK numbers to search\n    - page: Page number for pagination (default: 1)\n    - api_key: Your SEC API key","ref":"SecioEx.FullTextSearch.html#search/2-parameters","title":"Parameters - SecioEx.FullTextSearch.search/2","type":"function"},{"doc":"iex> SecioEx.FullTextSearch.search(\"SpaceX\", \n      form_types: [\"8-K\", \"10-Q\"],\n      start_date: \"2024-01-01\",\n      end_date: \"2024-03-31\",\n      api_key: \"your_api_key\"\n    )\n    {:ok, %{total: %{value: 86, relation: \"eq\"}, filings: [...]}}\n\n    # Search with exact phrase\n    iex> SecioEx.FullTextSearch.search(\"\"substantial doubt\"\",\n      form_types: [\"10-K\"],\n      api_key: \"your_api_key\"\n    )","ref":"SecioEx.FullTextSearch.html#search/2-examples","title":"Examples - SecioEx.FullTextSearch.search/2","type":"function"},{"doc":"Helper function to search with multiple terms using OR.","ref":"SecioEx.FullTextSearch.html#search_any_of/2","title":"SecioEx.FullTextSearch.search_any_of/2","type":"function"},{"doc":"iex> SecioEx.FullTextSearch.search_any_of([\"qualified opinion\", \"except for\"],\n      api_key: \"your_api_key\"\n    )","ref":"SecioEx.FullTextSearch.html#search_any_of/2-examples","title":"Examples - SecioEx.FullTextSearch.search_any_of/2","type":"function"},{"doc":"Helper function to search for an exact phrase.","ref":"SecioEx.FullTextSearch.html#search_exact_phrase/2","title":"SecioEx.FullTextSearch.search_exact_phrase/2","type":"function"},{"doc":"iex> SecioEx.FullTextSearch.search_exact_phrase(\"substantial doubt\",\n      api_key: \"your_api_key\"\n    )","ref":"SecioEx.FullTextSearch.html#search_exact_phrase/2-examples","title":"Examples - SecioEx.FullTextSearch.search_exact_phrase/2","type":"function"},{"doc":"Helper function to search with wildcards.","ref":"SecioEx.FullTextSearch.html#search_wildcard/2","title":"SecioEx.FullTextSearch.search_wildcard/2","type":"function"},{"doc":"iex> SecioEx.FullTextSearch.search_wildcard(\"gas\",\n      api_key: \"your_api_key\"\n    )","ref":"SecioEx.FullTextSearch.html#search_wildcard/2-examples","title":"Examples - SecioEx.FullTextSearch.search_wildcard/2","type":"function"},{"doc":"A mapping of various ids, tickers, etc.","ref":"SecioEx.MappingApi.html","title":"SecioEx.MappingApi","type":"module"},{"doc":"Lists all companies on a given exchange.","ref":"SecioEx.MappingApi.html#list_by_exchange/2","title":"SecioEx.MappingApi.list_by_exchange/2","type":"function"},{"doc":"iex> SecioEx.MappingApi.list_by_exchange(\"NASDAQ\", api_key: \"your_api_key\")\n    {:ok, [%{\n      \"name\" => \"Company1\",\n      \"exchange\" => \"NASDAQ\",\n      ...\n    }]}","ref":"SecioEx.MappingApi.html#list_by_exchange/2-examples","title":"Examples - SecioEx.MappingApi.list_by_exchange/2","type":"function"},{"doc":"Lists all companies in a given industry.","ref":"SecioEx.MappingApi.html#list_by_industry/2","title":"SecioEx.MappingApi.list_by_industry/2","type":"function"},{"doc":"iex> SecioEx.MappingApi.list_by_industry(\"Auto Manufacturers\", api_key: \"your_api_key\")\n    {:ok, [%{\n      \"name\" => \"Company1\",\n      \"industry\" => \"Auto Manufacturers\",\n      ...\n    }]}","ref":"SecioEx.MappingApi.html#list_by_industry/2-examples","title":"Examples - SecioEx.MappingApi.list_by_industry/2","type":"function"},{"doc":"Lists all companies in a given sector.","ref":"SecioEx.MappingApi.html#list_by_sector/2","title":"SecioEx.MappingApi.list_by_sector/2","type":"function"},{"doc":"iex> SecioEx.MappingApi.list_by_sector(\"Technology\", api_key: \"your_api_key\")\n    {:ok, [%{\n      \"name\" => \"Company1\",\n      \"sector\" => \"Technology\",\n      ...\n    }]}","ref":"SecioEx.MappingApi.html#list_by_sector/2-examples","title":"Examples - SecioEx.MappingApi.list_by_sector/2","type":"function"},{"doc":"Maps a CIK to company details.","ref":"SecioEx.MappingApi.html#map_cik/2","title":"SecioEx.MappingApi.map_cik/2","type":"function"},{"doc":"- cik: The CIK number (without leading zeros)\n  - opts: Keyword list of options including :api_key","ref":"SecioEx.MappingApi.html#map_cik/2-parameters","title":"Parameters - SecioEx.MappingApi.map_cik/2","type":"function"},{"doc":"iex> SecioEx.MappingApi.map_cik(\"1318605\", api_key: \"your_api_key\")\n    {:ok, [%{\n      \"name\" => \"Tesla Inc\",\n      \"ticker\" => \"TSLA\",\n      \"cik\" => \"1318605\",\n      \"cusip\" => \"88160R101\",\n      \"exchange\" => \"NASDAQ\",\n      \"isDelisted\" => false,\n      ...\n    }]}","ref":"SecioEx.MappingApi.html#map_cik/2-examples","title":"Examples - SecioEx.MappingApi.map_cik/2","type":"function"},{"doc":"Maps a CUSIP to company details.","ref":"SecioEx.MappingApi.html#map_cusip/2","title":"SecioEx.MappingApi.map_cusip/2","type":"function"},{"doc":"iex> SecioEx.MappingApi.map_cusip(\"88160R101\", api_key: \"your_api_key\")\n    {:ok, [%{\n      \"name\" => \"Tesla Inc\",\n      \"cusip\" => \"88160R101\",\n      ...\n    }]}","ref":"SecioEx.MappingApi.html#map_cusip/2-examples","title":"Examples - SecioEx.MappingApi.map_cusip/2","type":"function"},{"doc":"Maps a company name to company details.","ref":"SecioEx.MappingApi.html#map_name/2","title":"SecioEx.MappingApi.map_name/2","type":"function"},{"doc":"iex> SecioEx.MappingApi.map_name(\"Tesla\", api_key: \"your_api_key\")\n    {:ok, [%{\n      \"name\" => \"Tesla Inc\",\n      ...\n    }]}","ref":"SecioEx.MappingApi.html#map_name/2-examples","title":"Examples - SecioEx.MappingApi.map_name/2","type":"function"},{"doc":"Maps a ticker symbol to company details.","ref":"SecioEx.MappingApi.html#map_ticker/2","title":"SecioEx.MappingApi.map_ticker/2","type":"function"},{"doc":"iex> SecioEx.MappingApi.map_ticker(\"TSLA\", api_key: \"your_api_key\")\n    {:ok, [%{\n      \"name\" => \"Tesla Inc\",\n      \"ticker\" => \"TSLA\",\n      ...\n    }]}","ref":"SecioEx.MappingApi.html#map_ticker/2-examples","title":"Examples - SecioEx.MappingApi.map_ticker/2","type":"function"},{"doc":"","ref":"SecioEx.MappingApi.html#t:mapping_opts/0","title":"SecioEx.MappingApi.mapping_opts/0","type":"type"},{"doc":"The query api for working with SEC filings","ref":"SecioEx.QueryApi.html","title":"SecioEx.QueryApi","type":"module"},{"doc":"Performs a search query against the SEC Filings API.","ref":"SecioEx.QueryApi.html#search/2","title":"SecioEx.QueryApi.search/2","type":"function"},{"doc":"- query: String containing the Lucene query syntax\n  - opts: Keyword list of options\n    - from: Starting position for pagination (default: 0)\n    - size: Number of results per page (default: 50, max: 50)\n    - sort: List of sort criteria (default: [%{\"filedAt\" => %{\"order\" => \"desc\"}}])\n    - api_key: Your SEC API key","ref":"SecioEx.QueryApi.html#search/2-parameters","title":"Parameters - SecioEx.QueryApi.search/2","type":"function"},{"doc":"iex> SecioEx.QueryApi.search(\"formType:\"10-Q\"\", api_key: \"your_api_key\")\n    {:ok, %{\"total\" => %{\"value\" => 10000, \"relation\" => \"gte\"}, \"filings\" => [...]}}","ref":"SecioEx.QueryApi.html#search/2-examples","title":"Examples - SecioEx.QueryApi.search/2","type":"function"},{"doc":"Helper function to search filings within a date range.","ref":"SecioEx.QueryApi.html#search_by_date_range/3","title":"SecioEx.QueryApi.search_by_date_range/3","type":"function"},{"doc":"iex> SecioEx.QueryApi.search_by_date_range(\"2024-01-01\", \"2024-01-31\", api_key: \"your_api_key\")\n    {:ok, %{\"total\" => %{\"value\" => 3000, \"relation\" => \"eq\"}, \"filings\" => [...]}}","ref":"SecioEx.QueryApi.html#search_by_date_range/3-examples","title":"Examples - SecioEx.QueryApi.search_by_date_range/3","type":"function"},{"doc":"Helper function to search filings by ticker symbol.","ref":"SecioEx.QueryApi.html#search_by_ticker/2","title":"SecioEx.QueryApi.search_by_ticker/2","type":"function"},{"doc":"iex> SecioEx.QueryApi.search_by_ticker(\"AAPL\", api_key: \"your_api_key\")\n    {:ok, %{\"total\" => %{\"value\" => 5000, \"relation\" => \"eq\"}, \"filings\" => [...]}}","ref":"SecioEx.QueryApi.html#search_by_ticker/2-examples","title":"Examples - SecioEx.QueryApi.search_by_ticker/2","type":"function"},{"doc":"Helper function to search for specific form types.","ref":"SecioEx.QueryApi.html#search_form_type/2","title":"SecioEx.QueryApi.search_form_type/2","type":"function"},{"doc":"iex> SecioEx.QueryApi.search_form_type(\"10-K\", api_key: \"your_api_key\")\n    {:ok, %{\"total\" => %{\"value\" => 10000, \"relation\" => \"gte\"}, \"filings\" => [...]}}","ref":"SecioEx.QueryApi.html#search_form_type/2-examples","title":"Examples - SecioEx.QueryApi.search_form_type/2","type":"function"},{"doc":"A WebSocket client for streaming SEC (Securities and Exchange Commission) filing data \nin real-time using the sec-api.io service.","ref":"SecioEx.StreamApi.html","title":"SecioEx.StreamApi","type":"module"},{"doc":"# Define a custom callback to process 8-K filings\n    custom_callback = fn\n      [%{\"formType\" => form_type, \"entities\" => entities, \"linkToTxt\" => link_to_txt}]\n          when form_type in [\"8-K\", \"8-K/A\"] ->\n        IO.puts(\"Entities: #{inspect(entities)}\")\n        IO.puts(\"Form Type: #{form_type}\")\n        IO.puts(\"Link to HTML: #{link_to_txt}\\n\\n\")\n\n      _ ->\n        IO.puts(\"Form type not matched or unexpected data structure\\n \")\n    end\n\n    # Start the WebSocket connection\n    {:ok, pid} = SecioEx.StreamApi.sec_stream(\"your_api_key_here\", custom_callback)","ref":"SecioEx.StreamApi.html#module-example-usage","title":"Example Usage - SecioEx.StreamApi","type":"module"},{"doc":"Internal callback that handles incoming WebSocket messages.\nDecodes JSON messages and passes them to the specified callback function.","ref":"SecioEx.StreamApi.html#handle_frame/2","title":"SecioEx.StreamApi.handle_frame/2","type":"function"},{"doc":"* `{:text, msg}` - Tuple containing the received WebSocket frame\n  * `state` - Current callback function","ref":"SecioEx.StreamApi.html#handle_frame/2-parameters","title":"Parameters - SecioEx.StreamApi.handle_frame/2","type":"function"},{"doc":"* `{:ok, state}` - Tuple indicating successful message processing","ref":"SecioEx.StreamApi.html#handle_frame/2-returns","title":"Returns - SecioEx.StreamApi.handle_frame/2","type":"function"},{"doc":"Establishes a WebSocket connection to the SEC API streaming service.","ref":"SecioEx.StreamApi.html#sec_stream/2","title":"SecioEx.StreamApi.sec_stream/2","type":"function"},{"doc":"* `api_key` - Your SEC API authentication key\n  * `callback` - Optional function to process incoming messages. Defaults to `default_callback/1`","ref":"SecioEx.StreamApi.html#sec_stream/2-parameters","title":"Parameters - SecioEx.StreamApi.sec_stream/2","type":"function"},{"doc":"* `{:ok, pid}` - On successful connection\n  * `{:error, term}` - On failure","ref":"SecioEx.StreamApi.html#sec_stream/2-returns","title":"Returns - SecioEx.StreamApi.sec_stream/2","type":"function"},{"doc":"SecioEx.StreamApi.sec_stream(\"your_api_key_here\")\n    SecioEx.StreamApi.sec_stream(\"your_api_key_here\", &MyModule.process_filing/1)","ref":"SecioEx.StreamApi.html#sec_stream/2-example","title":"Example - SecioEx.StreamApi.sec_stream/2","type":"function"}],"producer":{"name":"ex_doc","version":"0.35.0"},"proglang":"elixir"}